## Summary
<!-- Brief description of changes -->

## Type of Change
- [ ] Bug fix
- [ ] New feature
- [ ] New connector (source/destination)
- [ ] Documentation
- [ ] Refactoring
- [ ] Other: ___

## Changes Made
<!-- Bullet points of what changed -->
-

## Testing
<!-- How did you test this? -->
- [ ] Unit tests added/updated
- [ ] Manual testing performed
- [ ] Existing tests pass (`uv run pytest`)

## Checklist
- [ ] Code follows project style (`make format`)
- [ ] Self-review completed
- [ ] Documentation updated (if needed)

## Related Issues
<!-- Link any related issues: Fixes #123 -->
